{% for master in masters -%}
{{ master.hostname }} ansible_host={{ hostvars[master.hostname]['ansible_host'] }}
{% endfor -%}
{% for node in nodes -%}
{{ node.hostname }} ansible_host={{ hostvars[node.hostname]['ansible_host'] }}
{% endfor %}

[k8sdc:children]
k8sdc-masters
k8sdc-nodes
etcd
fileserver
k8sdc-ca
timeserver
docker-registry-mirror

[k8sdc:vars]
ansible_ssh_user=root
ansible_connection=ssh
ansible_private_key_file=keys/{{ do_ssh_key_name }}

[k8sdc-masters]
{% for master in masters -%}
{{ master.hostname }}
{% endfor %}

[k8sdc-nodes]
{% for node in nodes -%}
{{ node.hostname }}
{% endfor %}

[etcd]
{% for etcd in etcd -%}
{{ etcd }}
{% endfor %}

[fileserver]
{{ fileserver }}

[k8sdc-ca]
{{ k8sdc_ca }}

[timeserver]
{{ timeserver }}

[docker-registry-mirror]
{{ docker_registry_mirror }}
